from typing import List

from transformers import AutoTokenizer, AutoModelForTokenClassification, pipeline, Pipeline, PreTrainedTokenizer

from experiment.sentence_wer_processor.sentence_wer_processor import SentenceWerProcessor


class WikineuralMultilingualNerTransformersWerProcessorBase(SentenceWerProcessor):
    _tokenizer: PreTrainedTokenizer
    _model: AutoModelForTokenClassification
    _pipeline: Pipeline

    def __init__(self, gold_transcript_property_name: str, asr_property_name: str, alignment_property_name: str,
                 wer_property_name: str, task_name: str, require_update: bool):
        super().__init__(gold_transcript_property_name, asr_property_name, alignment_property_name, wer_property_name,
                         task_name, require_update)
        self._tokenizer = AutoTokenizer.from_pretrained("Babelscape/wikineural-multilingual-ner")
        self._model = AutoModelForTokenClassification.from_pretrained("Babelscape/wikineural-multilingual-ner")
        self._pipeline = pipeline("ner", model=self._model, tokenizer=self._tokenizer)

    def process_text(self, text: str) -> List[str]:
        ner_results = self._pipeline(text)
        to_return = [''] * len(self._tokenizer.encode(text))
        for it in ner_results:
            to_return[it['index']] = it['entity']
        return to_return
